@@ -8,6 +8,7 @@ import click
 from sagify.api import local as api_local
 from sagify.commands import ASCII_LOGO
 from sagify.log import logger
+from future.moves import subprocess
 
 click.disable_unicode_literals_warning = True
 
@@ -36,6 +37,9 @@ def train(dir):
     except ValueError:
         logger.info("This is not a sagify directory: {}".format(dir))
         sys.exit(-1)
+    except subprocess.CalledProcessError as e:
+        logger.debug(e.output)
+        raise
     except Exception as e:
         logger.info("{}".format(e))
         return
@@ -55,6 +59,9 @@ def deploy(dir):
     except ValueError:
         logger.info("This is not a sagify directory: {}".format(dir))
         sys.exit(-1)
+    except subprocess.CalledProcessError as e:
+        logger.debug(e.output)
+        raise
     except Exception as e:
         logger.info("{}".format(e))
         return
